==> kpogre-1.2.7.tar.gz: kpogre-1.2.7/kpogre/DbObjects/kpgtablecolumn.h <==
/***************************************************************************
                          kpgtablecolumn  -  description
                             -------------------
    begin                : So no 7 2004
    copyright            : (C) 2004 by Lumir Vanek
    email                : lvanek@users.sourceforge.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
#ifndef KPGTABLECOLUMN_H
#define KPGTABLECOLUMN_H

#include "kpgtreeitem.h"

class KPGTableColumnsFolder;

/**
Table column

@author Lumir Vanek
*/

class KPGTableColumn : public KPGTreeItem
{
public:
  KPGTableColumn(KPGTableColumnsFolder *, const QString);
	KPGTableColumn(KPGTableColumnsFolder *, KPGTableColumn *, const QString);
  ~KPGTableColumn();
  
	virtual eNodeType type() const { return nodeTableColumn; }
  void setProperties(pqxx::oid, pqxx::oid, const QString, const QString, int, int, int,	int, int,	bool,	bool,	bool,	bool,	bool, const QString, int, const QString, const QString);
	void displayProperties(QWidget *);
	virtual bool refresh() { return true; }
	static QPixmap *getPixmapForType(const QString &);
  
  pqxx::oid getOidBaseType() const { return m_oidBaseType; }
  int attNum() const { return m_iAttNum; }
  const QString typName() const { return m_strTypName; }
  int iAttNdims() const { return m_iAttNdims; }
  bool hasDefault() const { return m_bHasDef; }
  bool isNotNull() const { return m_bNotNull; }
  const QString &defaultValue() const { return m_strAdSrc; }
  const QString storage() const { return m_strStorage; }
  int  statTarget() const { return m_iStatTarget; }
protected:
// Object properties
	// name is stored as text(0)
	pqxx::oid m_oidType;
  pqxx::oid m_oidBaseType;
	QString m_strTypName;
	QString m_strDescription;
	int	m_iStatTarget;
	int m_iAttLen;
	int m_iAttNum; 
	int m_iAttNdims;
	int m_iAttTypmod;
	bool m_bByVal;
	bool m_bNotNull;
	bool m_bHasDef;
	bool m_bIsDropped;
	bool m_bIsLocal;
  QString m_strStorage;
	int m_iInhCount;
	QString m_strAdSrc;
	QString m_strNspName;
};

#endif

==> kpogre-1.5.2.tar.gz: kpogre-1.5.2/kpogre/DbObjects/kpgtablecolumn.h <==
/***************************************************************************
                          kpgtablecolumn  -  description
                             -------------------
    begin                : So no 7 2004
    copyright            : (C) 2004 by Lumir Vanek
    email                : lvanek@users.sourceforge.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
#ifndef KPGTABLECOLUMN_H
#define KPGTABLECOLUMN_H

#include "kpgtreeitem.h"

class KPGTableColumnsFolder;

/**
Table column

@author Lumir Vanek
*/

class KPGTableColumn : public KPGTreeItem
{
public:
	KPGTableColumn(KPGTableColumnsFolder *, const QString);
	KPGTableColumn(KPGTableColumnsFolder *, KPGTableColumn *, const QString);
  	~KPGTableColumn();
  
	virtual eNodeType type() const { return nodeTableColumn; }
  	void setProperties(pqxx::oid, pqxx::oid, const QString &, const QString &, int, int, int,	int, int,	bool,	bool,	bool,	bool,	bool, const QString &, int, const QString &, const QString &);
  	
  	  	// Refresh. Behavior depends from type of object
	virtual bool refresh() { return refreshItem(); }
	
	// Refresh only this item, not childs
	virtual bool refreshItem();
  	
	void displayProperties(QWidget *);
	
	static QPixmap *getPixmapForType(const QString &);
  	pqxx::oid getOidBaseType() const { return m_oidBaseType; }
	int attNum() const { return m_iAttNum; }
	const QString &typName() const { return m_strTypName; }
	int iAttNdims() const { return m_iAttNdims; }
	bool hasDefault() const { return m_bHasDef; }
	bool isNotNull() const { return m_bNotNull; }
	const QString &defaultValue() const { return m_strAdSrc; }
	const QString &storage() const { return m_strStorage; }
	int  statTarget() const { return m_iStatTarget; }
	const QString &getDescription() const { return m_strDescription; }

protected:
	// Object properties
	// name is stored as text(0)
	pqxx::oid m_oidType;
  	pqxx::oid m_oidBaseType;
	QString m_strTypName;
	QString m_strDescription;
	int	m_iStatTarget;
	int m_iAttLen;
	int m_iAttNum; 
	int m_iAttNdims;
	int m_iAttTypmod;
	bool m_bByVal;
	bool m_bNotNull;
	bool m_bHasDef;
	bool m_bIsDropped;
	bool m_bIsLocal;
  	QString m_strStorage;
	int m_iInhCount;
	QString m_strAdSrc;
	QString m_strNspName;
};

#endif
